==> internet_services-5.x-2.6.tar.gz: internet_services/template.php <==
<?php
// $Id: template.php,v 1.6.2.6 2008/06/19 07:42:11 hswong3i Exp $

/**
 * Add custom.css if file exist.
 */
$custom_css = path_to_theme() .'/custom.css';
if (file_exists($custom_css)) {
  drupal_add_css($custom_css, 'theme');
}

/**
 * Return a themed search form from search-theme-form.tpl.php.
 */
function phptemplate_search_theme_form($form) {
  return _phptemplate_callback('search-theme-form', array('form' => $form));
}

/**
 * Return a themed primary menu.
 */
function internet_services_primary($items = array()) {
  $menu = menu_get_item(variable_get('menu_primary_menu', 0));
  $output = '<div class="title">' . $menu['title'] . '</div>';
  $output .= theme('links', $items, array('class' => 'primary-links'));
  return $output;
}

/**
 * Sets the body-tag class attribute.
 *
 * @return
 *   'sidebar-left', 'sidebar-right', 'both-sidebars' or 'no-sidebars'
 *   classes as needed.
 */
function phptemplate_body_class($sidebar_left, $sidebar_right) {
  if ($sidebar_left != '' && $sidebar_right != '') {
    $class = 'two-sidebars';
  }
  else {
    if ($sidebar_left != '') {
      $class = 'sidebar-left';
    }
    if ($sidebar_right != '') {
      $class = 'sidebar-right';
    }
  }

  return $class ? $class : 'no-sidebars';
}

/**
 * Return a themed mission trail.
 *
 * @return
 *   a string containing the mission output, or execute PHP code snippet if
 *   mission is enclosed with <?php ?>.
 */
function internet_services_mission() {
  $mission = theme_get_setting('mission');
  if (preg_match('/^<\?php/', $mission)) {
    $mission = drupal_eval($mission);
  }
  else {
    $mission = filter_xss_admin($mission);
  }
  return isset($mission) ? $mission : '';
}

==> internet_services-5.x-2.8.tar.gz: internet_services/template.php <==
<?php
// $Id: template.php,v 1.6.2.7 2008/06/26 18:39:56 hswong3i Exp $

/**
 * Add custom.css if file exist.
 */
$custom_css = path_to_theme() .'/custom.css';
if (file_exists($custom_css)) {
  drupal_add_css($custom_css, 'theme');
}

/**
 * Return a themed search form from search-theme-form.tpl.php.
 */
function phptemplate_search_theme_form($form) {
  return _phptemplate_callback('search-theme-form', array('form' => $form));
}

/**
 * Return a themed primary menu.
 */
function internet_services_primary($items = array()) {
  $menu = menu_get_item(variable_get('menu_primary_menu', 0));
  $output = '<div class="title">' . $menu['title'] . '</div>';
  $output .= theme('links', $items);
  return $output;
}

/**
 * Sets the body-tag class attribute.
 *
 * @return
 *   'sidebar-left', 'sidebar-right', 'both-sidebars' or 'no-sidebars'
 *   classes as needed.
 */
function phptemplate_body_class($sidebar_left, $sidebar_right) {
  if ($sidebar_left != '' && $sidebar_right != '') {
    $class = 'two-sidebars';
  }
  else {
    if ($sidebar_left != '') {
      $class = 'sidebar-left';
    }
    if ($sidebar_right != '') {
      $class = 'sidebar-right';
    }
  }

  return $class ? $class : 'no-sidebars';
}

/**
 * Return a themed mission trail.
 *
 * @return
 *   a string containing the mission output, or execute PHP code snippet if
 *   mission is enclosed with <?php ?>.
 */
function internet_services_mission() {
  $mission = theme_get_setting('mission');
  if (preg_match('/^<\?php/', $mission)) {
    $mission = drupal_eval($mission);
  }
  else {
    $mission = filter_xss_admin($mission);
  }
  return isset($mission) ? $mission : '';
}
